@@ -1,9 +1,9 @@
-// Copyright(C) 1999-2023 National Technology & Engineering Solutions
+// Copyright(C) 1999-2024 National Technology & Engineering Solutions
 // of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
 // NTESS, the U.S. Government retains certain rights in this software.
 //
 // See packages/seacas/LICENSE for details
 #pragma once
 
-static std::string version("3.28");
-static std::string verdate("2023-11-14");
+static const std::string version("3.32");
+static const std::string verdate("2024-03-08");
