@@ -7,7 +7,7 @@
 #include <array>
 #include <string>
 
-static std::array<std::string, 3> qainfo{
+static const std::array<std::string, 3> qainfo{
     "slice",
     "2023/09/14",
     "2.1.05",
